==> cosmo_1.12.0.zip: cosmo/doc/cosmo.R <==
###################################################
### chunk number 1: load
###################################################
library(cosmo) 


###################################################
### chunk number 2: rseqArgs
###################################################
args(rseq)


###################################################
### chunk number 3: pwm
###################################################
data(motifPWM)
motifPWM


###################################################
### chunk number 4: seqLogo1
###################################################
seqLogo(motifPWM)


###################################################
### chunk number 5: transMats
###################################################
data(transMats)
transMats



###################################################
### chunk number 6: rseqEx
###################################################
simSeqs <- rseq(20, 100, 1.0, motifPWM, transMats, "ZOOPS")
simSeqs$motifs



###################################################
### chunk number 7: makeConSetArg
###################################################
args(makeConSet)


###################################################
### chunk number 8: makeConSetEx
###################################################
conSet1 <- makeConSet(numInt=3, type=c("B","V","B"),length=c(3,NA,3))


###################################################
### chunk number 9: printConSet
###################################################
conSet1


###################################################
### chunk number 10: boundCon1
###################################################
boundCon1 <- makeBoundCon(lower=1.0, upper=2.0)


###################################################
### chunk number 11: boundCon2
###################################################
boundCon2 <- makeBoundCon(lower=0.0, upper=1.0)


###################################################
### chunk number 12: palCon
###################################################
palCon1 <- makePalCon(int1=1, int2=3, errBnd=0.05)


###################################################
### chunk number 13: addCon
###################################################
constraint <- list(boundCon1, boundCon2, palCon1)
int <- list(1, 2, NA)
conSet1 <- addCon(conSet=conSet1, constraint=constraint, int=int)
conSet1


###################################################
### chunk number 14: conSet2
###################################################
conSet2 <- makeConSet(numInt=1, type="V",length=NA)
subCon1 <- makeSubMotifCon(submotif="TATA",minfreq=0.9)
conSet2 <- addCon(conSet=conSet2, constraint=subCon1, int=NA)
conSet2


###################################################
### chunk number 15: cosmoArgs
###################################################
args(cosmo)


###################################################
### chunk number 16: cosmoClass
###################################################
slotNames("cosmo")


###################################################
### chunk number 17: example1
###################################################
seqFile <- system.file("Exfiles/seq.fasta", package="cosmo")
res <- cosmo(seqs=seqFile, constraints=list(conSet1, conSet2) , minW=7, maxW=8, models=c("OOPS", "TCM")) 


###################################################
### chunk number 18: printPwm
###################################################
print(res)


###################################################
### chunk number 19: summary
###################################################
summary(res)


###################################################
### chunk number 20: candModels
###################################################
res@cand


###################################################
### chunk number 21: motifs
###################################################
summary(res@motifs)


###################################################
### chunk number 22: seqLogo2
###################################################
plot(res)


###################################################
### chunk number 23: postprob
###################################################
plot(res, type="prob")


###################################################
### chunk number 24: bgModelArgs
###################################################
args(bgModel)


###################################################
### chunk number 25: bgModelEx
###################################################
bgFile <- system.file("Exfiles", "bgSeqs", package="cosmo")
tm <- bgModel(bgFile)


###################################################
### chunk number 26: bgModelOutput
###################################################
tm


###################################################
### chunk number 27: tmatEx
###################################################
res <- cosmo(seqs=seqFile, constraints="None" , minW=8, maxW=8, models="OOPS", transMat=tm$transMat)


###################################################
### chunk number 28: tmatExOut
###################################################
res 


###################################################
### chunk number 29: bfileEx
###################################################
bfile <- system.file("Exfiles", "bfile", package="cosmo")
s1 <- scan(file = bfile, what = "", sep = "\n", quote = "", 
           allowEscapes = FALSE, quiet = TRUE)
cat(paste(s1,collapse="\n"))


###################################################
### chunk number 30: bfile2tmat
###################################################
tmat <- bfile2tmat(bfile)
tmat

==> cosmo_1.16.0.zip: cosmo/doc/cosmo.R <==
###################################################
### chunk number 1: load
###################################################
#line 443 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp6Ioqkw/R.INSTALL24f7b5d/cosmo/inst/doc/cosmo.Rnw"
library(cosmo) 


###################################################
### chunk number 2: rseqArgs
###################################################
#line 451 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp6Ioqkw/R.INSTALL24f7b5d/cosmo/inst/doc/cosmo.Rnw"
args(rseq)


###################################################
### chunk number 3: pwm
###################################################
#line 508 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp6Ioqkw/R.INSTALL24f7b5d/cosmo/inst/doc/cosmo.Rnw"
data(motifPWM)
motifPWM


###################################################
### chunk number 4: seqLogo1
###################################################
#line 518 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp6Ioqkw/R.INSTALL24f7b5d/cosmo/inst/doc/cosmo.Rnw"
seqLogo(motifPWM)


###################################################
### chunk number 5: transMats
###################################################
#line 526 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp6Ioqkw/R.INSTALL24f7b5d/cosmo/inst/doc/cosmo.Rnw"
data(transMats)
transMats



###################################################
### chunk number 6: rseqEx
###################################################
#line 534 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp6Ioqkw/R.INSTALL24f7b5d/cosmo/inst/doc/cosmo.Rnw"
simSeqs <- rseq(20, 100, 1.0, motifPWM, transMats, "ZOOPS")
simSeqs$motifs



###################################################
### chunk number 7: makeConSetArg
###################################################
#line 549 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp6Ioqkw/R.INSTALL24f7b5d/cosmo/inst/doc/cosmo.Rnw"
args(makeConSet)


###################################################
### chunk number 8: makeConSetEx
###################################################
#line 557 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp6Ioqkw/R.INSTALL24f7b5d/cosmo/inst/doc/cosmo.Rnw"
conSet1 <- makeConSet(numInt=3, type=c("B","V","B"),length=c(3,NA,3))


###################################################
### chunk number 9: printConSet
###################################################
#line 563 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp6Ioqkw/R.INSTALL24f7b5d/cosmo/inst/doc/cosmo.Rnw"
conSet1


###################################################
### chunk number 10: boundCon1
###################################################
#line 571 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp6Ioqkw/R.INSTALL24f7b5d/cosmo/inst/doc/cosmo.Rnw"
boundCon1 <- makeBoundCon(lower=1.0, upper=2.0)


###################################################
### chunk number 11: boundCon2
###################################################
#line 575 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp6Ioqkw/R.INSTALL24f7b5d/cosmo/inst/doc/cosmo.Rnw"
boundCon2 <- makeBoundCon(lower=0.0, upper=1.0)


###################################################
### chunk number 12: palCon
###################################################
#line 580 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp6Ioqkw/R.INSTALL24f7b5d/cosmo/inst/doc/cosmo.Rnw"
palCon1 <- makePalCon(int1=1, int2=3, errBnd=0.05)


###################################################
### chunk number 13: addCon
###################################################
#line 585 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp6Ioqkw/R.INSTALL24f7b5d/cosmo/inst/doc/cosmo.Rnw"
constraint <- list(boundCon1, boundCon2, palCon1)
int <- list(1, 2, NA)
conSet1 <- addCon(conSet=conSet1, constraint=constraint, int=int)
conSet1


###################################################
### chunk number 14: conSet2
###################################################
#line 593 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp6Ioqkw/R.INSTALL24f7b5d/cosmo/inst/doc/cosmo.Rnw"
conSet2 <- makeConSet(numInt=1, type="V",length=NA)
subCon1 <- makeSubMotifCon(submotif="TATA",minfreq=0.9)
conSet2 <- addCon(conSet=conSet2, constraint=subCon1, int=NA)
conSet2


###################################################
### chunk number 15: cosmoArgs
###################################################
#line 605 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp6Ioqkw/R.INSTALL24f7b5d/cosmo/inst/doc/cosmo.Rnw"
args(cosmo)


###################################################
### chunk number 16: cosmoClass
###################################################
#line 679 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp6Ioqkw/R.INSTALL24f7b5d/cosmo/inst/doc/cosmo.Rnw"
slotNames("cosmo")


###################################################
### chunk number 17: example1
###################################################
#line 751 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp6Ioqkw/R.INSTALL24f7b5d/cosmo/inst/doc/cosmo.Rnw"
seqFile <- system.file("Exfiles/seq.fasta", package="cosmo")
res <- cosmo(seqs=seqFile, constraints=list(conSet1, conSet2) , minW=7, maxW=8, models=c("OOPS", "TCM")) 


###################################################
### chunk number 18: printPwm
###################################################
#line 756 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp6Ioqkw/R.INSTALL24f7b5d/cosmo/inst/doc/cosmo.Rnw"
print(res)


###################################################
### chunk number 19: summary
###################################################
#line 761 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp6Ioqkw/R.INSTALL24f7b5d/cosmo/inst/doc/cosmo.Rnw"
summary(res)


###################################################
### chunk number 20: candModels
###################################################
#line 766 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp6Ioqkw/R.INSTALL24f7b5d/cosmo/inst/doc/cosmo.Rnw"
res@cand


###################################################
### chunk number 21: motifs
###################################################
#line 782 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp6Ioqkw/R.INSTALL24f7b5d/cosmo/inst/doc/cosmo.Rnw"
summary(res@motifs)


###################################################
### chunk number 22: seqLogo2
###################################################
#line 795 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp6Ioqkw/R.INSTALL24f7b5d/cosmo/inst/doc/cosmo.Rnw"
plot(res)


###################################################
### chunk number 23: postprob
###################################################
#line 808 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp6Ioqkw/R.INSTALL24f7b5d/cosmo/inst/doc/cosmo.Rnw"
plot(res, type="prob")


###################################################
### chunk number 24: bgModelArgs
###################################################
#line 838 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp6Ioqkw/R.INSTALL24f7b5d/cosmo/inst/doc/cosmo.Rnw"
args(bgModel)


###################################################
### chunk number 25: bgModelEx
###################################################
#line 852 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp6Ioqkw/R.INSTALL24f7b5d/cosmo/inst/doc/cosmo.Rnw"
bgFile <- system.file("Exfiles", "bgSeqs", package="cosmo")
tm <- bgModel(bgFile)


###################################################
### chunk number 26: bgModelOutput
###################################################
#line 861 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp6Ioqkw/R.INSTALL24f7b5d/cosmo/inst/doc/cosmo.Rnw"
tm


###################################################
### chunk number 27: tmatEx
###################################################
#line 876 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp6Ioqkw/R.INSTALL24f7b5d/cosmo/inst/doc/cosmo.Rnw"
res <- cosmo(seqs=seqFile, constraints="None" , minW=8, maxW=8, models="OOPS", transMat=tm$transMat)


###################################################
### chunk number 28: tmatExOut
###################################################
#line 879 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp6Ioqkw/R.INSTALL24f7b5d/cosmo/inst/doc/cosmo.Rnw"
res 


###################################################
### chunk number 29: bfileEx
###################################################
#line 885 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp6Ioqkw/R.INSTALL24f7b5d/cosmo/inst/doc/cosmo.Rnw"
bfile <- system.file("Exfiles", "bfile", package="cosmo")
s1 <- scan(file = bfile, what = "", sep = "\n", quote = "", 
           allowEscapes = FALSE, quiet = TRUE)
cat(paste(s1,collapse="\n"))


###################################################
### chunk number 30: bfile2tmat
###################################################
#line 904 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp6Ioqkw/R.INSTALL24f7b5d/cosmo/inst/doc/cosmo.Rnw"
tmat <- bfile2tmat(bfile)
tmat
